@@ -14,7 +14,6 @@ package builder::xmake {
     #~ use File::ShareDir qw[];
     #
     my $version = '2.8.8';    # Target install version
-    my $try_git = !1;         # If true, source will be pulled (slowly) from git repos
 
     # If false, a complete archive is downloaded (quickly) via http
     #~ my $installer_sh = 'https://xmake.io/shget.text';
@@ -55,8 +54,8 @@ package builder::xmake {
             return $local;
         }
         $s->log_debug( 'Status: [' . $response->{status} . '] ' . $response->{content} );
-        $s->log_warn( 'Failed to download installer from ' . $response->{url} );
-        exit 1;
+        $s->log_warn( 'Failed to download ' . $response->{url} );
+        return ();
     }
 
     #~ sub download_shget {
@@ -196,7 +195,7 @@ package builder::xmake {
                     last;
                 }
             }
-            $make // warn 'Please install make/gmake';
+            $make // warn 'Please install gmake';
         }
         my $compiler;
         {
@@ -208,17 +207,8 @@ package builder::xmake {
                     $compiler = $_;
                 }
             }
-            $compiler // warn 'Please install a C compiler';
-        }
-        my $git;
-        if ($try_git) {
-            for (qw[git]) {
-                if ( system( $_, '--version' ) == 0 ) {
-                    $git = $_;
-                    last;
-                }
-            }
-            $git // warn 'Please install git';
+
+            #~ $compiler // warn 'Please install a C compiler';
         }
         if ( !defined $make || !defined $compiler ) {
             my $sudo      = sudo();
@@ -247,7 +237,11 @@ package builder::xmake {
                 #brew   => 'brew --version',                                       # MacOS
                 #dnf    => 'dnf --help',    # Fedora, RHEL, OpenSUSE, CentOS
             );
-            system $options{$installer} if defined $options{$installer};
+            warn 'You should probably try running ' . $options{$installer}
+                if defined $options{$installer};
+            my $prebuilt = install_prebuilt();
+            warn 'You could also install a prebuilt version of xmake with ' . $prebuilt
+                if defined $prebuilt;
         }
 
         sub get_host_speed {
@@ -273,7 +267,17 @@ package builder::xmake {
         my $cwd        = rel2abs('.');
         my $projectdir = tempdir( CLEANUP => 1 );
         my $workdir;
-        if ( defined $git ) {
+        my $archive = $s->download( $installer_tar, 'xmake.tar.gz' );
+        if ( !$archive ) {
+            warn 'Failed to download source snapshot... Looking for git...';
+            my $git;
+            for (qw[git]) {
+                if ( system( $_, '--version' ) == 0 ) {
+                    $git = $_;
+                    last;
+                }
+            }
+            if ( !$git ) { warn 'Cannot locate git. Giving up'; exit 1; }
             my $mirror = get_fast_host();
             CORE::say "Using $mirror mirror...";
             my ( $gitrepo, $gitrepo_raw );
@@ -293,14 +297,11 @@ package builder::xmake {
             chdir $projectdir;
             $workdir = $projectdir;
         }
-        else {
-            my $archive = $s->download( $installer_tar, 'xmake.tar.gz' );
-            my $tar     = Archive::Tar->new;
-            $tar->read($archive);
-            chdir $projectdir;
-            $tar->extract();
-            $workdir = $projectdir . '/xmake-' . $version;
-        }
+        my $tar = Archive::Tar->new;
+        $tar->read($archive);
+        chdir $projectdir;
+        $tar->extract();
+        $workdir = $projectdir . '/xmake-' . $version;
         chdir $workdir;
         system './configure' unless -f 'makefile';
         system $make, '--jobs=5';
